==> gchempaint-0.5.6.tar.bz2: gchempaint-0.5.6/lib/settings.h <==
// -*- C++ -*-

/* 
 * GChemPaint libray
 * settings.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GCHEMPAINT_SETTINGS_H
#define GCHEMPAINT_SETTINGS_H

#include <glib.h>
#include <pango/pango.h>

extern double DefaultBondLength;
extern double DefaultBondDist;
extern double DefaultBondWidth;
extern double DefaultArrowLength;
extern double DefaultHashWidth;
extern double DefaultHashDist;
extern double DefaultStereoBondWidth;
extern double DefaultZoomFactor;
extern double DefaultPadding;
extern double DefaultArrowHeadA;
extern double DefaultArrowHeadB;
extern double DefaultArrowHeadC;
extern double DefaultArrowDist;
extern double DefaultArrowPadding;
extern double DefaultStoichiometryPadding;
extern double DefaultObjectPadding;
extern double DefaultSignPadding;
extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
extern gchar* DefaultFontFamily;
extern PangoStyle DefaultFontStyle;
extern PangoWeight DefaultFontWeight;
extern PangoVariant DefaultFontVariant;
extern PangoStretch DefaultFontStretch;
extern gint DefaultFontSize;
extern unsigned MaxStackSize;

#endif // GCHEMPAINT_SETTINGS_H

==> gchempaint-0.7.4.tar.bz2: gchempaint-0.7.4/lib/settings.h <==
// -*- C++ -*-

/* 
 * GChemPaint libray
 * settings.h 
 *
 * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GCHEMPAINT_SETTINGS_H
#define GCHEMPAINT_SETTINGS_H

#include <glib.h>
#include <pango/pango.h>

/*
extern double DefaultBondLength;
extern double DefaultBondAngle;
extern double DefaultBondDist;
extern double DefaultBondWidth;
extern double DefaultArrowLength;
extern double DefaultHashWidth;
extern double DefaultHashDist;
extern double DefaultStereoBondWidth;
extern double DefaultZoomFactor;
extern double DefaultPadding;
extern double DefaultArrowHeadA;
extern double DefaultArrowHeadB;
extern double DefaultArrowHeadC;
extern double DefaultArrowDist;
extern double DefaultArrowPadding;
extern double DefaultStoichiometryPadding;
extern double DefaultObjectPadding;
extern double DefaultSignPadding;
extern double DefaultChargeSignHeight;
extern double DefaultChargeSignSize;
extern double DefaultChargeYAlign;*/
extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
/*extern gchar *DefaultFontFamily, *DefaultTextFontFamily;
extern PangoStyle DefaultFontStyle;
extern PangoWeight DefaultFontWeight;
extern PangoVariant DefaultFontVariant;
extern PangoStretch DefaultFontStretch;
extern gint DefaultFontSize;*/
extern unsigned MaxStackSize;
extern bool MergeAtoms;

#endif // GCHEMPAINT_SETTINGS_H
